"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AirshipStatus = void 0;
const util_1 = require("@skeldjs/util");
const constant_1 = require("@skeldjs/constant");
const InnerShipStatus_1 = require("./InnerShipStatus");
const systems_1 = require("../systems");
const __1 = require("../..");
/**
 * Represents a room object for the Airship map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class AirshipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netid, ownerid, flags, data) {
        super(room, spawnType, netid, ownerid, flags, data);
        this.initialSpawnCenter = new util_1.Vector2(50, 50);
        this.meetingSpawnCenter = new util_1.Vector2(50, 50);
    }
    getComponent(component) {
        if (component === AirshipStatus) {
            return this.components[0];
        }
        return super.getComponent(component);
    }
    async _handleCloseDoorsOfType(rpc) {
        const electricaldoors = this.systems.get(constant_1.SystemType.Decontamination);
        const doorsInRoom = AirshipStatus.roomDoors[rpc.systemId];
        for (const doorId of doorsInRoom) {
            electricaldoors.closeDoor(doorId);
        }
    }
    Setup() {
        this.systems.set(constant_1.SystemType.Electrical, new systems_1.SwitchSystem(this, {
            expected: [false, false, false, false, false],
            actual: [false, false, false, false, false],
            brightness: 255,
        }));
        this.systems.set(constant_1.SystemType.MedBay, new systems_1.MedScanSystem(this, {
            queue: []
        }));
        this.systems.set(constant_1.SystemType.Doors, new systems_1.DoorsSystem(this, {
            doors: [],
            cooldowns: new Map
        }));
        this.systems.set(constant_1.SystemType.Communications, new systems_1.HudOverrideSystem(this, {
            sabotaged: false,
        }));
        this.systems.set(constant_1.SystemType.GapRoom, new systems_1.MovingPlatformSystem(this, {
            target: undefined,
            side: systems_1.MovingPlatformSide.Left,
            useId: 0,
        }));
        this.systems.set(constant_1.SystemType.Decontamination, new systems_1.ElectricalDoorsSystem(this, {
            doors: [],
        }));
        this.systems.set(constant_1.SystemType.Decontamination2, new systems_1.AutoDoorsSystem(this, {
            dirtyBit: 0,
            doors: [],
        }));
        this.systems.set(constant_1.SystemType.Sabotage, new systems_1.SabotageSystem(this, {
            cooldown: 0,
        }));
        this.systems.set(constant_1.SystemType.Security, new systems_1.SecurityCameraSystem(this, {
            players: new Set,
        }));
        const electricaldoors = this.systems.get(constant_1.SystemType.Decontamination);
        electricaldoors.doors = [
            new __1.Door(electricaldoors, 0, true),
            new __1.Door(electricaldoors, 1, true),
            new __1.Door(electricaldoors, 2, true),
            new __1.Door(electricaldoors, 3, true),
            new __1.Door(electricaldoors, 4, true),
            new __1.Door(electricaldoors, 5, true),
            new __1.Door(electricaldoors, 6, true),
            new __1.Door(electricaldoors, 7, true),
            new __1.Door(electricaldoors, 8, true),
            new __1.Door(electricaldoors, 9, true),
            new __1.Door(electricaldoors, 10, true),
            new __1.Door(electricaldoors, 11, true)
        ];
        const autodoors = this.systems.get(constant_1.SystemType.Decontamination2);
        autodoors.doors = [
            new __1.AutoOpenDoor(autodoors, 15, true),
            new __1.AutoOpenDoor(autodoors, 16, true),
            new __1.AutoOpenDoor(autodoors, 17, true),
            new __1.AutoOpenDoor(autodoors, 18, true)
        ];
    }
}
exports.AirshipStatus = AirshipStatus;
AirshipStatus.roomDoors = {
    [constant_1.SystemType.Communications]: [0, 1, 2, 3],
    [constant_1.SystemType.Brig]: [4, 5, 6],
    [constant_1.SystemType.Kitchen]: [7, 8, 9],
    [constant_1.SystemType.MainHall]: [10, 11],
    [constant_1.SystemType.Records]: [12, 13, 14],
    [constant_1.SystemType.Lounge]: [15, 16, 17, 18],
    [constant_1.SystemType.Medical]: [19, 20]
};
//# sourceMappingURL=AirshipStatus.js.map